@@ -43,7 +43,7 @@ test_that("all left and right intervals are reported with both arg", {
   out_left <- bed_flank(x, genome, left = dist)
   out_right <- bed_flank(x, genome, right = dist)
   out_both <- bed_flank(x, genome, both = dist)
-  out_left_right <- dplyr::bind_rows(out_left, out_right) %>%
+  out_left_right <- dplyr::bind_rows(out_left, out_right) |>
     arrange(chrom, start)
   expect_true(all(out_both == out_left_right))
 })
